@@ -8,13 +8,14 @@
 */
 
 #include "Polkit1Backend.h"
+#include "kauthdebug.h"
 
-#include <qplugin.h>
 #include <QCoreApplication>
 #include <QTimer>
+#include <qplugin.h>
 
-#include <QApplication>
-#include <QWidget>
+#include <QGuiApplication>
+#include <QWindow>
 
 #include <QDBusConnection>
 #include <QDBusConnectionInterface>
@@ -22,29 +23,23 @@
 #include <PolkitQt1/Subject>
 #include <polkitqt1-version.h>
 
-#include "kauthdebug.h"
-
 namespace KAuth
 {
-
 Polkit1Backend::Polkit1Backend()
     : AuthBackend()
 {
-    setCapabilities(AuthorizeFromHelperCapability | CheckActionExistenceCapability | PreAuthActionCapability);
+    setCapabilities(AuthorizeFromHelperCapability | PreAuthActionCapability);
 
     // Setup useful signals
-    connect(PolkitQt1::Authority::instance(), SIGNAL(configChanged()),
-            this, SLOT(checkForResultChanged()));
-    connect(PolkitQt1::Authority::instance(), SIGNAL(consoleKitDBChanged()),
-            this, SLOT(checkForResultChanged()));
+    connect(PolkitQt1::Authority::instance(), &PolkitQt1::Authority::configChanged, this, &KAuth::Polkit1Backend::checkForResultChanged);
+    connect(PolkitQt1::Authority::instance(), &PolkitQt1::Authority::consoleKitDBChanged, this, &KAuth::Polkit1Backend::checkForResultChanged);
 }
 
 Polkit1Backend::~Polkit1Backend()
 {
-
 }
 
-void Polkit1Backend::preAuthAction(const QString &action, QWidget *parent)
+void Polkit1Backend::preAuthAction(const QString &action, QWindow *parent)
 {
     // If a parent was not specified, skip this
     if (!parent) {
@@ -55,17 +50,18 @@ void Polkit1Backend::preAuthAction(const QString &action, QWidget *parent)
     // Are we running our KDE auth agent?
     if (QDBusConnection::sessionBus().interface()->isServiceRegistered(QLatin1String("org.kde.polkit-kde-authentication-agent-1"))) {
         // Check if we actually are entitled to use GUI capabilities
-        if (qApp == nullptr || !qobject_cast<QApplication *>(qApp)) {
+        if (!qGuiApp) {
             qCDebug(KAUTH) << "Not streaming parent as we are on a TTY application";
         }
 
         // Retrieve the dialog root window Id
-        qulonglong wId = parent->effectiveWinId();
+        qulonglong wId = parent->winId();
 
         // Send it over the bus to our agent
-        QDBusMessage methodCall =
-            QDBusMessage::createMethodCall(QLatin1String("org.kde.polkit-kde-authentication-agent-1"), QLatin1String("/org/kde/Polkit1AuthAgent"), QLatin1String("org.kde.Polkit1AuthAgent"),
-                                           QLatin1String("setWIdForAction"));
+        QDBusMessage methodCall = QDBusMessage::createMethodCall(QLatin1String("org.kde.polkit-kde-authentication-agent-1"),
+                                                                 QLatin1String("/org/kde/Polkit1AuthAgent"),
+                                                                 QLatin1String("org.kde.Polkit1AuthAgent"),
+                                                                 QLatin1String("setWIdForAction"));
 
         methodCall << action;
         methodCall << wId;
@@ -97,8 +93,7 @@ Action::AuthStatus Polkit1Backend::actionStatus(const QString &action)
 {
     PolkitQt1::SystemBusNameSubject subject(QString::fromUtf8(callerID()));
     auto authority = PolkitQt1::Authority::instance();
-    PolkitQt1::Authority::Result r = authority->checkAuthorizationSync(action, subject,
-                                     PolkitQt1::Authority::None);
+    PolkitQt1::Authority::Result r = authority->checkAuthorizationSync(action, subject, PolkitQt1::Authority::None);
 
     if (authority->hasError()) {
         qCDebug(KAUTH) << "Encountered error while checking action status, error code:" << authority->lastError() << authority->errorDetails();
@@ -119,7 +114,7 @@ Action::AuthStatus Polkit1Backend::actionStatus(const QString &action)
 
 QByteArray Polkit1Backend::callerID() const
 {
-        return QDBusConnection::systemBus().baseService().toUtf8();
+    return QDBusConnection::systemBus().baseService().toUtf8();
 }
 
 AuthBackend::ExtraCallerIDVerificationMethod Polkit1Backend::extraCallerIDVerificationMethod() const
@@ -143,7 +138,6 @@ bool Polkit1Backend::isCallerAuthorized(const QString &action, const QByteArray
         e.quit();
     });
 
-
 #if POLKITQT1_IS_VERSION(0, 113, 0)
     authority->checkAuthorizationWithDetails(action, subject, PolkitQt1::Authority::AllowUserInteraction, polkit1Details);
 #else
@@ -170,28 +164,23 @@ void Polkit1Backend::checkForResultChanged()
         const QString action = it.key();
         if (it.value() != actionStatus(action)) {
             *it = actionStatus(action);
-            emit actionStatusChanged(action, *it);
+            Q_EMIT actionStatusChanged(action, *it);
         }
     }
 }
 
-bool Polkit1Backend::actionExists(const QString &action)
-{
-    return m_cachedResults.value(action) != Action::InvalidStatus;
-}
-
 QVariantMap Polkit1Backend::backendDetails(const DetailsMap &details)
 {
     QVariantMap backendDetails;
     for (auto it = details.cbegin(); it != details.cend(); ++it) {
         switch (it.key()) {
-            case Action::AuthDetail::DetailMessage:
-                backendDetails.insert(QStringLiteral("polkit.message"), it.value());
-                break;
-            case Action::AuthDetail::DetailOther:
-            default:
-                backendDetails.insert(QStringLiteral("other_details"), it.value());
-                break;
+        case Action::AuthDetail::DetailMessage:
+            backendDetails.insert(QStringLiteral("polkit.message"), it.value());
+            break;
+        case Action::AuthDetail::DetailOther:
+        default:
+            backendDetails.insert(QStringLiteral("other_details"), it.value());
+            break;
         }
     }
     return backendDetails;
@@ -199,3 +188,4 @@ QVariantMap Polkit1Backend::backendDetails(const DetailsMap &details)
 
 } // namespace Auth
 
+#include "moc_Polkit1Backend.cpp"
